Index: content/browser/frame_host/frame_tree_node.h |
diff --git a/content/browser/frame_host/frame_tree_node.h b/content/browser/frame_host/frame_tree_node.h |
index 0358b0a29f2f56ab1db7189f9fb6073ccf596a6a..db332daed3c24c2608206e8a470473eba65a6f03 100644 |
--- a/content/browser/frame_host/frame_tree_node.h |
+++ b/content/browser/frame_host/frame_tree_node.h |
@@ -168,9 +168,9 @@ class CONTENT_EXPORT FrameTreeNode { |
// Clear any feature policy header associated with the frame. |
void ResetFeaturePolicyHeader(); |
- // Add CSP header to replication state, notify proxies about the update and |
- // enforce it on the browser. |
- void AddContentSecurityPolicy(const ContentSecurityPolicyHeader& header); |
+ // Add CSP headers to replication state, notify proxies about the update. |
+ void AddContentSecurityPolicies( |
+ const std::vector<ContentSecurityPolicyHeader>& headers); |
// Discards previous CSP headers and notifies proxies about the update. |
// Typically invoked after committing navigation to a new document (since the |